"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2018, Salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
const path = require('path');
const glob = require('glob');
const srcDevUtil = require(path.join(__dirname, '..', 'srcDevUtil'));
const MetadataRegistry = require(path.join(__dirname, '..', 'metadataRegistry'));
const defaultMetadataType_1 = require("./defaultMetadataType");
const PathUtil = require("../sourcePathUtil");
const almError = require("../almError");
class ExperienceBundleMetadataType extends defaultMetadataType_1.DefaultMetadataType {
    constructor(typeDefObj) {
        super(typeDefObj);
    }
    /**
     * During sfdx:source:push, given the meta file for the changed site, get all the files that needs to be pushed
     * if given metadataFilePath is of "baseDir/force-app/main/default/experiences/byo21-meta.xml"
     * we need to return the files in the bundle of the site corresponding to byo21-meta.xml meta file
     * ie., all the files in "baseDir/force-app/main/default/experiences/" dir (while ignoring the ones in forceIgnore file)
     */
    getOriginContentPathsForSourceConvert(metadataFilePath, workspaceVersion, unsupportedMimeTypes, forceIgnore) {
        const fileName = path.basename(metadataFilePath);
        const dirName = fileName.split(MetadataRegistry.getMetadataFileExt())[0];
        const bundlePaths = glob.sync(path.join(path.dirname(metadataFilePath), dirName, '**'), { nodir: true });
        return Promise.resolve(bundlePaths.filter(bundlePath => forceIgnore.accepts(bundlePath)));
    }
    /**
     * Get where the file will be placed in the temp mdDir dir
     *
     * @param originContentPath - origin path as in sfdx working dir
     * @param aggregateFullName
     * @param mdDir - temp folder path
     */
    getMdapiContentPathForSourceConvert(originContentPath, aggregateFullName, mdDir) {
        const mdapiSourceDir = this.getPathToMdapiSourceDir(aggregateFullName, mdDir);
        const relativePathDir = this.getRelativeContentPath(originContentPath);
        return this.getMdapiFormattedContentPath(mdapiSourceDir, relativePathDir);
    }
    getRelativeContentPath(contentPath) {
        return MetadataRegistry.splitOnDirName(this.typeDefObj.defaultDirectory, contentPath)[1];
    }
    /**
     * Given a path to the file in local working env, we should return the name of the site
     * If its a meta file, we just strip the -meta.xml to get the siteName
     * Otherwise, we return the grandparent directory (site name)
     * @param filePath
     */
    getAggregateFullNameFromFilePath(filePath) {
        if (filePath.endsWith(MetadataRegistry.getMetadataFileExt())) {
            const fileDir = filePath.split(path.sep);
            return fileDir[fileDir.length - 1].split(MetadataRegistry.getMetadataFileExt())[0];
        }
        return PathUtil.getGrandparentDirectoryName(filePath);
    }
    /**
     * Given a file, we need to return the corresponding site's meta file
     * @param filePath
     */
    getAggregateMetadataFilePathFromWorkspacePath(filePath) {
        if (filePath.endsWith(MetadataRegistry.getMetadataFileExt())) {
            return filePath;
        }
        const fileBrokenPaths = MetadataRegistry.splitOnDirName(this.typeDefObj.defaultDirectory, filePath);
        const metaXmlFileName = this.getMetaFileName(fileBrokenPaths[1]);
        return path.join(fileBrokenPaths[0], this.typeDefObj.defaultDirectory, metaXmlFileName);
    }
    getDefaultAggregateMetadataPath(fullName, defaultSourceDir, bundleFileProperties) {
        return path.join(defaultSourceDir, this.typeDefObj.defaultDirectory, this.getMetaFileName(fullName));
    }
    /**
     * The path of every file. Given the file location in base working dir of the meta file and
     * the temp location of a file of the corresponding site, we need to give where the file (in temp location) will sit in the
     * base working dir
     * @param metadataFilePath
     * @param retrievedContentFilePath
     */
    getWorkspaceContentFilePath(metadataFilePath, retrievedContentFilePath) {
        const workspaceDir = path.dirname(metadataFilePath);
        const fileName = MetadataRegistry.splitOnDirName(this.typeDefObj.defaultDirectory, retrievedContentFilePath)[1];
        return path.join(workspaceDir, fileName);
    }
    getRetrievedMetadataPath(fileProperty, retrieveRoot, bundleFileProperties) {
        const bundlePath = this.stripBundlePath(path.dirname(fileProperty.fileName));
        const fileName = this.getMetaFileName(fileProperty.fullName);
        const retrievedMetadataPath = path.join(retrieveRoot, bundlePath, fileName);
        if (srcDevUtil.pathExistsSync(retrievedMetadataPath)) {
            return retrievedMetadataPath;
        }
        else {
            throw almError('MissingMetadataFile', retrievedMetadataPath);
        }
    }
    /**
     * A bundlPath is of format /unpackaged/experiences/{siteName}/{type}
     * We just need /unpackaged/experiences, which is where the -meta.xml lives
     * @param bundlePath
     */
    stripBundlePath(bundlePath) {
        const folderPath = bundlePath.split(path.sep);
        return path.join(folderPath[0], folderPath[1]);
    }
    /**
     * fullName is of the format {siteName}/{type}/{componentName-WithoutSuffix}
     * To get -meta.xml, we just need {siteName} as it is of the format {siteName}-meta.xml
     * @param fullName
     */
    getMetaFileName(fullName) {
        if (fullName.startsWith(path.sep)) {
            fullName = fullName.slice(1);
        }
        const bundleName = fullName.split(path.sep)[0];
        return `${path.basename(bundleName)}${MetadataRegistry.getMetadataFileExt()}`;
    }
}
exports.ExperienceBundleMetadataType = ExperienceBundleMetadataType;

//# sourceMappingURL=experienceBundleMetadataType.js.map
