/*
 * Copyright (c) 2016, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root  or https://opensource.org/licenses/BSD-3-Clause
 */
'use strict';
// Node
const path = require('path');
const { Messages } = require('@salesforce/core');
// Local
const logger = require(path.join(__dirname, '..', 'logApi'));
Messages.importMessagesDirectory(__dirname);
const hammerTestUtils = require(path.join(__dirname, 'hammerTestUtils'));
const HammerTestApi = require(path.join(__dirname, 'hammerTestApi'));
const messagesHammerTestReport = Messages.loadMessages('salesforce-alm', 'package_hammertest_report');
class HammerTestReportCommand {
    constructor() {
        this.logger = logger.child('package:hammertest:report');
    }
    execute(context) {
        this.hammerTestApi = new HammerTestApi(context.org);
        const requestId = context.flags.requestid;
        this.summary = context.flags.summary;
        hammerTestUtils.validateIsvHammerRequestId(requestId);
        const result = this.hammerTestApi.viewHammerTestResult(requestId);
        return result;
    }
    /**
     * returns a human readable message for a cli output
     * @param output - data representing results of Hammer Run Request
     * @returns {string}
     */
    getHumanSuccessMessage(output) {
        if (this.summary) {
            const data = output.results.map(res => ({ subscriberOrgId: res.subscriberOrgId, result: res.result, status: res.status, message: res.message, lastModified: res.lastModified }));
            this._showTestReportSummary(data);
        }
        else {
            const data = output.results.map(res => ({ subscriberOrgId: res.subscriberOrgId, result: res.result, status: res.status, message: res.message, lastModified: res.lastModified, apexTestFailures: res.apexTestFailures }));
            this._showTestReportInDetail(data);
        }
        return messagesHammerTestReport.getMessage('humanSuccess');
    }
    _showTestReportSummary(summaryData) {
        this.logger.table(summaryData, { columns: [
                { key: 'subscriberOrgId', label: 'SubscriberOrgId' },
                { key: 'result', label: 'Result' },
                { key: 'status', label: 'Status' },
                { key: 'message', label: 'Message' },
                { key: 'lastModified', label: 'LastModified' }
            ] });
    }
    _showTestReportInDetail(data) {
        for (let i = 0; i < data.length; i++) {
            this.logger.styledHeader(this.logger.color.blue(`SubscriberOrgId: ${data[i].subscriberOrgId}`));
            this.logger.styledHeader(this.logger.color.blue(`Result: ${data[i].result}`));
            this.logger.styledHeader(this.logger.color.blue(`Status: ${data[i].status}`));
            this.logger.styledHeader(this.logger.color.blue(`LastModified: ${data[i].lastModified}`));
            if (data[i].message) {
                this.logger.styledHeader(this.logger.color.blue(`Message: ${data[i].message}`));
            }
            this._showApexTestFailuresTable(data[i]);
        }
    }
    _showApexTestFailuresTable(apexData) {
        const tfData = apexData.apexTestFailures.map(req => ({
            namespace: req.namespace,
            className: req.className,
            methodName: req.methodName,
            message: req.message,
            stackTrace: req.stackTrace,
            timeTaken: req.timeTaken,
            classId: req.classId,
            canSeeAllData: req.canSeeAllData
        }));
        if (tfData.length > 0) {
            this.logger.styledHeader(this.logger.color.red(messagesHammerTestReport.getMessage('packageTestFailures')));
            this.logger.table(tfData, {
                columns: [
                    { key: 'namespace', label: 'Namespace' },
                    { key: 'className', label: 'ClassName' },
                    { key: 'methodName', label: 'MethodName' },
                    { key: 'message', label: 'Message' },
                    { key: 'stackTrace', label: 'StackTrace' },
                    { key: 'timeTaken', label: 'TimeTaken' },
                    { key: 'classId', label: 'ClassId' },
                    { key: 'canSeeAllData', label: 'CanSeeAllData' }
                ]
            });
        }
        else {
            this.logger.styledHeader(this.logger.color.red(messagesHammerTestReport.getMessage('noPackageTestFailures')));
        }
    }
}
module.exports = HammerTestReportCommand;

//# sourceMappingURL=hammerTestReportCommand.js.map
