/*
 * Copyright, 1999-2016, salesforce.com
 * All Rights Reserved
 * Company Confidential
 */
'use strict';
// Node
const fs = require('fs');
const os = require('os');
const moment = require('moment');
const { SfdxError } = require('@salesforce/core');
const ID_REGISTRY = [
    {
        prefix: '04t',
        label: 'Subscriber Package Version Id'
    },
    {
        prefix: '00D',
        label: 'Subscriber Organization Id'
    },
    {
        prefix: '0TW',
        label: 'ISV Hammer Request Id'
    }
];
module.exports = {
    BY_LABEL: (function () {
        const byLabels = {};
        ID_REGISTRY.forEach((id) => {
            byLabels[id.label.replace(/ /g, '_').toUpperCase()] = id;
        });
        return byLabels;
    })(),
    validateId(idObj, value) {
        if (!value || (value.length !== 15 && value.length !== 18)) {
            return false;
        }
        return (Array.isArray(idObj)) ? idObj.some(e => value.startsWith(e.prefix)) : value.startsWith(idObj.prefix);
    },
    parseSubscriberOrgIds(context) {
        let subscriberCsvList;
        if (context.flags.subscriberorg) {
            subscriberCsvList = context.flags.subscriberorg.split(',');
        }
        else if (context.flags.subscriberfile) {
            subscriberCsvList = this.getSubscriberOrgsFromFile(context.flags.subscriberfile);
        }
        const subscriberOrgIds = [];
        subscriberCsvList.forEach(subscriberOrgId => {
            const tempOrgId = this.cleanUpSubscriberOrgId(subscriberOrgId);
            if (tempOrgId) {
                subscriberOrgIds.push(tempOrgId);
            }
        });
        return subscriberOrgIds;
    },
    validateAndGetScheduledRunDateTime(scheduledDateTime) {
        const format = 'YYYY-MM-DD HH:mm:ss'; // todo: this time needs to be in GMT
        if (!scheduledDateTime) {
            return moment().format(format);
        }
        if (moment(scheduledDateTime).isValid()) {
            return scheduledDateTime;
        }
        throw SfdxError.create('salesforce-alm', 'package_hammertest', 'invalidScheduledDate', [scheduledDateTime]);
    },
    validateSubscriberPackageVersionId(apvId) {
        if (!this.validateId(this.BY_LABEL.SUBSCRIBER_PACKAGE_VERSION_ID, apvId)) {
            throw SfdxError.create('salesforce-alm', 'package_hammertest', 'invalidPackageVersionId', [apvId]);
        }
    },
    validateIsvHammerRequestId(requestId) {
        if (!this.validateId(this.BY_LABEL.ISV_HAMMER_REQUEST_ID, requestId)) {
            throw SfdxError.create('salesforce-alm', 'package_hammertest', 'invalidIdOrRequest', [requestId]);
        }
    },
    /**
     * Validate and clean up a given string as an orgId
     * @param {string} subscriberOrg
     * @returns {string}
     */
    cleanUpSubscriberOrgId(subscriberOrg) {
        // todo: is there a nice way to do null check?
        subscriberOrg = subscriberOrg.trim();
        if (!subscriberOrg) {
            return '';
        }
        if (!this.validateId(this.BY_LABEL.SUBSCRIBER_ORGANIZATION_ID, subscriberOrg)) {
            throw SfdxError.create('salesforce-alm', 'package_hammertest', 'invalidSubscriberOrgId', [subscriberOrg]);
        }
        return subscriberOrg;
    },
    getSubscriberOrgsFromFile(subscriberFile) {
        if (!fs.existsSync(subscriberFile)) {
            throw SfdxError.create('salesforce-alm', 'package_hammertest', 'pathDoesNotExist', [subscriberFile]);
        }
        const fileContent = fs.readFileSync(subscriberFile, 'utf8');
        if (!fileContent) {
            throw SfdxError.create('salesforce-alm', 'package_hammertest', 'emptyFile', [subscriberFile]);
        }
        return fileContent.split(os.EOL);
    }
};

//# sourceMappingURL=hammerTestUtils.js.map
